@@ -59,6 +59,10 @@ const char kDotfile_Help[] =
 
     gn gen out/Debug --root=/home/build --dotfile=/home/my_gn_file.gn
 
+  The system variable `gn_version` is available in the dotfile, but none of
+  the other variables are, because the dotfile is processed before args.gn
+  or anything else is processed.
+
 Variables
 
   arg_file_template [optional]
@@ -403,6 +407,9 @@ Setup::Setup()
       dotfile_scope_(&dotfile_settings_) {
   dotfile_settings_.set_toolchain_label(Label());
 
+  dotfile_provider_ =
+      std::make_unique<ScopePerFileProvider>(&dotfile_scope_, false, true);
+
   build_settings_.set_item_defined_callback(
       [task_runner = scheduler_.task_runner(),
        builder = &builder_](std::unique_ptr<Item> item) {
@@ -1100,7 +1107,7 @@ bool Setup::FillOtherConfig(const base::CommandLine& cmdline, Err* err) {
   if (!exec_script_allowlist_value) {
     // Check for this value as well, for backwards-compatibility.
     exec_script_allowlist_value =
-      dotfile_scope_.GetValue("exec_script_whitelist", true);
+        dotfile_scope_.GetValue("exec_script_whitelist", true);
   }
 
   if (exec_script_allowlist_value) {
